@@ -5,8 +5,8 @@ Created on Mon Dec 25 22:28:49 2017
 
 @author: albintveitankappi
 """
-import items
-import tiles
+import escapetheforest.items
+import escapetheforest.tiles
 
 # Things to fix:
 # LeaveForrestTile cant be in the middle of the forrest, thats silly! But then again, the person playing the game 
@@ -17,7 +17,7 @@ import tiles
 # Im thinking its time to introduce an NPC that its possible to hold a conversation with! An old man in a hut? 
 # A troll, at first appearing to be a stone?
 
-import world
+import escapetheforest.world
 from escapetheforest.player import Player
 
 def play():
